pub fn fitness<S: CalcType + Tokenizer + Default>(
text: &str,
reference_data: &HashMap<S::Key, f64>,
penalty_score: f64,
) -> f64Expand description
Calculate closeness of given text to reference data. the closer the result is to zero, the closer the text is to the reference data. (the less probably ones are closer to -infty\
reference_data is frequency of given S type
text should be normalized as it will check what it see, so for most cases upper latters and no spaces<