pub enum VigenereAttackResult {
KeyStringProbability(Vec<(String, f64)>),
KeyCharProbability(Vec<Vec<(char, f64)>>),
}Variants
KeyStringProbability(Vec<(String, f64)>)
It uses fitness to measure probability that given key is the correct one
KeyCharProbability(Vec<Vec<(char, f64)>>)
It check every char by itself, so it return probability that given one is the correct one