VigenereDictionaryAttack

Struct VigenereDictionaryAttack 

pub struct VigenereDictionaryAttack<'a, S>
where S: CalcType + Tokenizer + Clone + Default,
{ /* private fields */ }
Crack Vigenere by trying every given key

It calculate fitness of every key. The closer the value to zero, the more probably that given key was the correct one

reference_data should not have spaces inside as they will be trimmed