VigenereVariationalAttack

Struct VigenereVariationalAttack 

pub struct VigenereVariationalAttack<'a, S>
where S: CalcType + Tokenizer,
{ /* private fields */ }
If later found some char that fit the best in given index, the best char in previous index may change. it may need a rerun

okey, umm, so. it’s not that easly. I really have to write algortithm that will rerun it… but how? how to be sure taht given char is correct?

Okey, it even isn’t for breaking as it doesn’t return Result<Vec<(String, f64)>, CipherError>