pub enum CaseStrategy {
CaseSensitive,
CaseUnsensitive,
Preserve,
}Expand description
Which strategy to use for case
Variants
CaseSensitive
A ≠ a
Alphabet can have same letters if in different case.
Example
let alphabet = &['A', 'a', 'B', 'b', 'C', 'c'];“A, a, B, b, C, c,…”
CaseUnsensitive
Preserve
The case of the letter will remain the same after encrypting or decrypting:
ggzLCB ⇒ cipHER
Alphabet can only have uppercase letters.
Example
let alphabet = &['A', 'B', 'C'];Trait Implementations
Sourceimpl Clone for CaseStrategy
impl Clone for CaseStrategy
Sourcefn clone(&self) -> CaseStrategy
fn clone(&self) -> CaseStrategy
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CaseStrategy
impl Debug for CaseStrategy
Sourceimpl Default for CaseStrategy
impl Default for CaseStrategy
Sourcefn default() -> CaseStrategy
fn default() -> CaseStrategy
Returns the “default value” for a type. Read more
Sourceimpl Display for CaseStrategy
impl Display for CaseStrategy
Sourceimpl ValueEnum for CaseStrategy
impl ValueEnum for CaseStrategy
impl Copy for CaseStrategy