pub fn index_of_coincidence(text: &str) -> f64Expand description
text should be normalized It return some number, every language has their own result from IoC Random text normally is much lower than what languages returns If text.len() <2 it will return 0