pub enum IoC {
En,
Pl,
Fr,
De,
It,
Pt,
Ru,
Es,
}Expand description
Index of coincidence
Choose which language to use
Variants
Implementations
Sourceimpl IoC
impl IoC
Sourcepub fn value(&self) -> f64
pub fn value(&self) -> f64
Return value of given IoC
This should be used for now for this crate.
The values were divided by 26 (number of english letters).
Pl values were calculated by me, the rest are from wikipedia
For normalized results, use value_normalized()
Example
use cryptography_breaker::IoC;
let english_ioc_value = IoC::En.value();
assert_eq!(0.0665, english_ioc_value)Sourcepub fn value_normalized(&self) -> f64
pub fn value_normalized(&self) -> f64
Return normalized value of given IoC
The calculated values are normalized by multiply the results by number of letters
Pl values were calculated by me, the rest are from wikipedia
For normalized results, use value_normalized()
Example
use cryptography_breaker::IoC;
let english_ioc_value_normalized = IoC::En.value_normalized();
assert_eq!(1.729, english_ioc_value_normalized)Trait Implementations